/*
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

package dk.sosi.seal.pki.impl.federationcert;

import dk.sosi.seal.pki.FederationCertificateReference;
import dk.sosi.seal.pki.PKIException;
import dk.sosi.seal.pki.SOSIConfiguration;
import dk.sosi.seal.pki.impl.HashMapCertificateCache;
import dk.sosi.seal.pki.impl.PropertiesSOSIConfiguration;
import org.junit.*;
import org.junit.rules.ExpectedException;


/**
 */
public class TestFederationCertificateStoreAdapter {

    private FederationCertificateStoreAdapter adapter;

    @Rule
    public ExpectedException expectedEx = ExpectedException.none();

    @Before
    public void setUp() throws Exception {
        final SOSIConfiguration sosiConfiguration = PropertiesSOSIConfiguration.createWithDefaultOcesTestProperties(System.getProperties());
        adapter = new FederationCertificateStoreAdapter(sosiConfiguration, new HashMapCertificateCache());
    }

    @After
    public void tearDown() throws Exception {
        adapter = null;
    }

    @Test
    public void testInvalidOCES1Reference() {
        expectedEx.expect(PKIException.class);
        expectedEx.expectMessage("OCES-version OCES1 is not supported.");

        final FederationCertificateReference reference = new FederationCertificateReference("OCES1,CVR:55832218-UID:1163447368627,1077430095");
        adapter.getFederationCertificate(reference);
    }
}